==> OpenOLAP_V1.0.zip: OpenOLAP/src/viewer/target/spread/js/spreadFunc.js <==
	// =====================================================
	// ʕϐ
	// =====================================================
	// Object i[p
	var spreadTable   = null;	// SpreadzupTABLEvf
	var dataTableArea = null;	// f[^\͂DIVvf
	var dataTable     = null;	// f[^\TABLEvf
	var colHeader     = null;	// wb_\͂SPANvf
	var rowHeader     = null;	// swb_\͂SPANvf
	var CRSHeaderObject = null;	// NXwb_[͂SAPNvf

	// Spread \֘A
	var defaultCellWidth  = 100;	// \̗wb_̕
	var defaultCellHeight = 22; 	// \̍swb_̍

	// i[p
	var axesXMLData;

	// swb_Awb_ɃZbgꂽ/W[
	var rowObjNum = 0;
	var colObjNum = 0;

	// swb_Awb_̊ei̎/W[̃o
	var chMemNumList = new Array(3);
		chMemNumList[0] = 0;
		chMemNumList[1] = 0;
		chMemNumList[2] = 0;

	var rhMemNumList = new Array(3);
		rhMemNumList[0] = 0;
		rhMemNumList[1] = 0;
		rhMemNumList[2] = 0;

	// XML̐ݒ
	var memberElementsNum = 7;		// XML̎ovf
	var isDrilledPosition = 5;		// XMĹuisDrilledvindex(0 start)


	// ===================================================================================
	// ֐
	// ===================================================================================

	// ===== ֐ ==================================================================

	// Spread̏
	function loadSpread() {
		axesXMLData = parent.info_area.axesXMLData;

		//PageEdgeɎ/W[̃XCX{^𐶐A\(visibilityvisibleɕύX)
		showSlicerButton();

		// ======== ϐ̏(S) ========
		// IuWFNg
		spreadTable   = document.all("SpreadTable");
		dataTableArea = document.all("DataTableArea");
		dataTable     = dataTableArea.firstChild;
		colHeader     = document.all("ColumnHeaderArea");
		rowHeader     = document.all("RowHeaderArea");
		CRSHeaderObject = document.all("CrossHeaderArea");


		// swb_Awb_ɃZbgꂽ/W[
		var metaDataArea = document.all("metaDataArea");
		colObjNum = parseInt(metaDataArea.all("colHiesCount").innerText);
		rowObjNum = parseInt(metaDataArea.all("rowHiesCount").innerText);

		// swb_Awb_ɃZbgꂽ/W[̃o
		chMemNumList[0] = parseInt(metaDataArea.all("colHie0Count").innerText);
		chMemNumList[1] = parseInt(metaDataArea.all("colHie1Count").innerText);
		chMemNumList[2] = parseInt(metaDataArea.all("colHie2Count").innerText);

		rhMemNumList[0] = parseInt(metaDataArea.all("rowHie0Count").innerText);
		rhMemNumList[1] = parseInt(metaDataArea.all("rowHie1Count").innerText);
		rhMemNumList[2] = parseInt(metaDataArea.all("rowHie2Count").innerText);

		// ======== ϐ̏(hp) ========
		viewedColSpreadKeyList[0] = document.SpreadForm.viewCol0KeyList_hidden.value;
		viewedColSpreadKeyList[1] = document.SpreadForm.viewCol1KeyList_hidden.value;
		viewedColSpreadKeyList[2] = document.SpreadForm.viewCol2KeyList_hidden.value;

		viewedRowSpreadKeyList[0] = document.SpreadForm.viewRow0KeyList_hidden.value;
		viewedRowSpreadKeyList[1] = document.SpreadForm.viewRow1KeyList_hidden.value;
		viewedRowSpreadKeyList[2] = document.SpreadForm.viewRow2KeyList_hidden.value;

		viewedColSpreadIndexKeyList = document.SpreadForm.viewColIndexKey_hidden.value;
		viewedRowSpreadIndexKeyList = document.SpreadForm.viewRowIndexKey_hidden.value;

		// ݃EChEɕ\Ă/sSpreadIndex,KEY̑gݍ킹
		var colIndexKeysStringArray = viewedColSpreadIndexKeyList.split(",");
		for ( var i = 0; i < colIndexKeysStringArray.length; i++ ) {
			var indexKeysString = colIndexKeysStringArray[i];
			var indexKeysArray = indexKeysString.split(":");

			var spreadIndex = parseInt(indexKeysArray[0]);
			var keyArray = indexKeysArray[1].split(";");

			viewingColSpreadIndexKeysDict.add(spreadIndex, keyArray);
		}

		var rowIndexKeysStringArray = viewedRowSpreadIndexKeyList.split(",");
		for ( var i = 0; i < rowIndexKeysStringArray.length; i++ ) {
			var indexKeysString = rowIndexKeysStringArray[i];
			var indexKeysArray = indexKeysString.split(":");

			var spreadIndex = parseInt(indexKeysArray[0]);
			var keyArray = indexKeysArray[1].split(";");

			viewingRowSpreadIndexKeysDict.add(spreadIndex, keyArray);
		}

		// Azz̏(COL KEY)
		for ( var i = 0; i < viewedColSpreadKeyList.length; i++) {
			var tmpKeyArray = viewedColSpreadKeyList[i].split(",");

			for ( var j = 0; j < tmpKeyArray.length; j++ ) {
				var tmpKey = tmpKeyArray[j].toString();

				associationViewedColSpreadKey[i][tmpKey] = 1;
			}
		}

		// Azz̏(COL Index)
		var tmpIndexKeyArray = viewedColSpreadIndexKeyList.split(",");

		for ( var j = 0; j < tmpIndexKeyArray.length; j++ ) {
			var tmpIndexKey = tmpIndexKeyArray[j].toString();
			var tmpIndex = tmpIndexKey.split(":")[0].toString();

			associationViewedColSpreadIndex[tmpIndex] = 1;
		}

		// Azz̏(ROW KEY)
		for ( var i = 0; i < viewedRowSpreadKeyList.length; i++) {
			var tmpKeyArray = viewedRowSpreadKeyList[i].split(",");

			for ( var j = 0; j < tmpKeyArray.length; j++ ) {
				var tmpKey = tmpKeyArray[j].toString();

				associationViewedRowSpreadKey[i][tmpKey] = 1;
			}
		}

		// Azz̏(ROW Index)
		var tmpIndexKeyArray = viewedRowSpreadIndexKeyList.split(",");

		for ( var j = 0; j < tmpIndexKeyArray.length; j++ ) {
			var tmpIndexKey = tmpIndexKeyArray[j].toString();
			var tmpIndex = tmpIndexKey.split(":")[0].toString();

			associationViewedRowSpreadIndex[tmpIndex] = 1;
		}

		// ===== swb_ȉꍇA炩߃wb_Z̕Lăo悤ɂĂ =====
		if ( getHeaderObjNum("ROW") > 1 ) {
			for ( var j = 0; j < getHeaderObjNum("ROW"); j++ ) {
				changeCellWidth(document.all("CrossHeader_CG" + j), 40, "modifyCrossHeaderWidth", "UP");
			}
		}

		// ===== swb_Awb_Af[^\̕A𒲐 =====
		resizeArea();

		// ===== XN[CxgscrollView()Ƃ̑Ήt =====
		dataTableArea.onscroll = scrollView;

		// ===== Spreade[u̐FAf[^ǂݍ݁ASpread̕\(visibilityvisibleɕύX) =====
		refreshTableColor();

	}

	

	// HTML̃e[uɐFݒKpAɃf[^}Ăяo
	function refreshTableColor() {
		document.SpreadForm.action = "Controller?action=loadColorAct";
		document.SpreadForm.target = "loadingStatus";
		document.SpreadForm.submit();
	}


	// ===== T[oւ̃ANZXǂݒ ========================================
	function setLoadingStatus(status) {
		if ( (status != true) && (status != false) ) {
			return;
		}

		if (status == true) { // T[o[փANZX
			parent.spread_header.loadingStatus.loadingIMG.src = "./images/logo_anime.gif";
		} else { // T[o[ւ̃ANZXI
			parent.spread_header.loadingStatus.loadingIMG.src = "./images/logo_anime_stop.gif";
		}
	}

	// ============= X^C֘A֐ =====================================

	// swb_ƃf[^e[ũXN[ʒu킹
	function scrollView() {
		rowHeader.scrollTop = dataTableArea.scrollTop;
		colHeader.scrollLeft= dataTableArea.scrollLeft;
	}

	// swb_Awb_Af[^\̕BODYTCYɍ킹ĕύXB
	function resizeArea() {
		if ( document.body.clientWidth != 0 ) {

			var newWidth  = ( document.body.clientWidth - rowHeader.offsetWidth ) 
			var newHeight = ( document.body.clientHeight 
			                   - document.all("tblToolBar").offsetHeight 
			                   - colHeader.offsetHeight 
			                   - spreadTable.rows[0].offsetHeight 
			                   - spreadTable.rows[1].offsetHeight 
			                 ) 

			// swb_Af[^\̕їwb_Af[^\̍
			// ɂȂꍇ́A␳͍sȂȂ
			if ( newWidth <= 0 ) {
				return;
			} else if ( newHeight <= 0 ) {
				return;
			}

			colHeader.style.width      = newWidth;
			dataTableArea.style.width  = newWidth;

			rowHeader.style.height     = newHeight;
			dataTableArea.style.height = newHeight;

			// sEwb_Af[^e[ũXN[ʒu(XAY)킹
			scrollView();
		}
	}

// ===== bZ[W\ =============================================

	// [U[ɃbZ[W\
	function showMessage( id,arg1,arg2,arg3,arg4,arg5 ) {

		var message    = "";
		var arg1String = "";
		var arg2String = "";
		var arg3String = "";
		var arg4String = "";
		var arg5String = "";

		switch ( id ) {
		
			case "1" :
				if ( arg1 == "COL" ) {
					arg1String = "wb_";
				} else if ( arg1 == "ROW" ) {
					arg1String = "swb_";
				}
				message = arg1String + "ɂ͂Piȏ̃fBV܂̓W[KvłB";
				break;

			case "2" :
				if ( arg1 == "COL" ) {
					arg1String = "wb_";
				} else if ( arg1 == "ROW" ) {
					arg1String = "swb_";
				}
				message = arg1String + "ɂ͂Riȏ̃fBV܂̓W[͐ݒł܂B";
				break;

			case "3" :
				if ( arg2 == "COL" ) {
					arg2String = "wb_";
				} else if ( arg2 == "ROW" ) {
					arg2String = "swb_";
				}
				message = arg2String + "ɕ\łZ̍ől" + arg1 + "łB";
				break;

			case "4" :
				message = "|[gɕ\łZ̍ől" + arg1 + "łB";
				break;

			case "5" :
				message = "hsĂ܂BXB";
				break;

			// ZN^
			case "6" :
				message = "Iς݂̃o[Ƀo[܂B";
				break;

			// |[gۑ
			case "7" :
				message = "|[gۑ܂B";
				break;

			// OC̓`FbNi[U[pX[hj
			case "8" :
				message = "[U[уpX[h͂ĂB";
				break;

			// OC̓`FbNi[U[j
			case "9" :
				message = "[U[͂ĂB";
				break;

			// OC̓`FbNipX[hj
			case "10" :
				message = "pX[h͂ĂB";
				break;


		}

		alert( message );
	}


	// [U[ɊmF߂郁bZ[W\
	function showConfirm(msgId,arg1){
		var msg=new Array();
		msg["CFM1"] = "OAEg܂B낵łH";
		return confirm(msg[msgId]);
	}

// ====================================================================================

	// ʃt[ŃOAEgɎgp
	function logout_flow(element, contextPath) {
		if ( showConfirm("CFM1") ) {
			element.href = contextPath + "/Controller?action=logout";
			element.target="_top";
		} else {
			return;
		}
	}

==> OpenOLAP_V1.2.0.zip: OpenOLAP/src/viewer/target/spread/js/spreadFunc.js <==
	// =====================================================
	// ʕϐ
	// =====================================================
	// Object i[p
	var spreadTable   = null;	// SpreadzupTABLEvf
	var dataTableArea = null;	// f[^\͂DIVvf
	var dataTable     = null;	// f[^\TABLEvf
	var colHeader     = null;	// wb_\͂SPANvf
	var rowHeader     = null;	// swb_\͂SPANvf
	var CRSHeaderObject = null;	// NXwb_[͂SAPNvf

	// Spread \֘A
	var defaultCellWidth  = 100;	// \̗wb_̕
	var defaultCellHeight = 22; 	// \̍swb_̍

	// i[p
	var axesXMLData;

	// swb_Awb_ɃZbgꂽ/W[
	var rowObjNum = 0;
	var colObjNum = 0;

	// swb_Awb_̊ei̎/W[̃o
	var chMemNumList = new Array(3);
		chMemNumList[0] = 0;
		chMemNumList[1] = 0;
		chMemNumList[2] = 0;

	var rhMemNumList = new Array(3);
		rhMemNumList[0] = 0;
		rhMemNumList[1] = 0;
		rhMemNumList[2] = 0;

	// XML̐ݒ
	var memberElementsNum = 7;		// XML̎ovf
	var isDrilledPosition = 5;		// XMĹuisDrilledvindex(0 start)

	// ===================================================================================
	// ֐
	// ===================================================================================

	// ===== ֐ ==================================================================

	// Spread̏
	function loadSpread() {
		axesXMLData = parent.info_area.axesXMLData;

		//PageEdgeɎ/W[̃XCX{^𐶐A\(visibilityvisibleɕύX)
		showSlicerButton();

		// ======== ϐ̏(S) ========
		// IuWFNg
		spreadTable   = document.all("SpreadTable");
		dataTableArea = document.all("DataTableArea");
		dataTable     = dataTableArea.firstChild;
		colHeader     = document.all("ColumnHeaderArea");
		rowHeader     = document.all("RowHeaderArea");
		CRSHeaderObject = document.all("CrossHeaderArea");


		// swb_Awb_ɃZbgꂽ/W[
		var metaDataArea = document.all("metaDataArea");
		colObjNum = parseInt(metaDataArea.all("colHiesCount").innerText);
		rowObjNum = parseInt(metaDataArea.all("rowHiesCount").innerText);

		// swb_Awb_ɃZbgꂽ/W[̃o
		chMemNumList[0] = parseInt(metaDataArea.all("colHie0Count").innerText);
		chMemNumList[1] = parseInt(metaDataArea.all("colHie1Count").innerText);
		chMemNumList[2] = parseInt(metaDataArea.all("colHie2Count").innerText);

		rhMemNumList[0] = parseInt(metaDataArea.all("rowHie0Count").innerText);
		rhMemNumList[1] = parseInt(metaDataArea.all("rowHie1Count").innerText);
		rhMemNumList[2] = parseInt(metaDataArea.all("rowHie2Count").innerText);

		// ======== ϐ̏(hp) ========
		viewedColSpreadKeyList[0] = document.SpreadForm.viewCol0KeyList_hidden.value;
		viewedColSpreadKeyList[1] = document.SpreadForm.viewCol1KeyList_hidden.value;
		viewedColSpreadKeyList[2] = document.SpreadForm.viewCol2KeyList_hidden.value;

		viewedRowSpreadKeyList[0] = document.SpreadForm.viewRow0KeyList_hidden.value;
		viewedRowSpreadKeyList[1] = document.SpreadForm.viewRow1KeyList_hidden.value;
		viewedRowSpreadKeyList[2] = document.SpreadForm.viewRow2KeyList_hidden.value;

		viewedColSpreadIndexKeyList = document.SpreadForm.viewColIndexKey_hidden.value;
		viewedRowSpreadIndexKeyList = document.SpreadForm.viewRowIndexKey_hidden.value;

		// ݃EChEɕ\Ă/sSpreadIndex,KEY̑gݍ킹
		var colIndexKeysStringArray = viewedColSpreadIndexKeyList.split(",");
		for ( var i = 0; i < colIndexKeysStringArray.length; i++ ) {
			var indexKeysString = colIndexKeysStringArray[i];
			var indexKeysArray = indexKeysString.split(":");

			var spreadIndex = parseInt(indexKeysArray[0]);
			var keyArray = indexKeysArray[1].split(";");

			viewingColSpreadIndexKeysDict.add(spreadIndex, keyArray);
		}

		var rowIndexKeysStringArray = viewedRowSpreadIndexKeyList.split(",");
		for ( var i = 0; i < rowIndexKeysStringArray.length; i++ ) {
			var indexKeysString = rowIndexKeysStringArray[i];
			var indexKeysArray = indexKeysString.split(":");

			var spreadIndex = parseInt(indexKeysArray[0]);
			var keyArray = indexKeysArray[1].split(";");

			viewingRowSpreadIndexKeysDict.add(spreadIndex, keyArray);
		}

		// Azz̏(COL KEY)
		for ( var i = 0; i < viewedColSpreadKeyList.length; i++) {
			var tmpKeyArray = viewedColSpreadKeyList[i].split(",");

			for ( var j = 0; j < tmpKeyArray.length; j++ ) {
				var tmpKey = tmpKeyArray[j].toString();

				associationViewedColSpreadKey[i][tmpKey] = 1;
			}
		}

		// Azz̏(COL Index)
		var tmpIndexKeyArray = viewedColSpreadIndexKeyList.split(",");

		for ( var j = 0; j < tmpIndexKeyArray.length; j++ ) {
			var tmpIndexKey = tmpIndexKeyArray[j].toString();
			var tmpIndex = tmpIndexKey.split(":")[0].toString();

			associationViewedColSpreadIndex[tmpIndex] = 1;
		}

		// Azz̏(ROW KEY)
		for ( var i = 0; i < viewedRowSpreadKeyList.length; i++) {
			var tmpKeyArray = viewedRowSpreadKeyList[i].split(",");

			for ( var j = 0; j < tmpKeyArray.length; j++ ) {
				var tmpKey = tmpKeyArray[j].toString();

				associationViewedRowSpreadKey[i][tmpKey] = 1;
			}
		}

		// Azz̏(ROW Index)
		var tmpIndexKeyArray = viewedRowSpreadIndexKeyList.split(",");

		for ( var j = 0; j < tmpIndexKeyArray.length; j++ ) {
			var tmpIndexKey = tmpIndexKeyArray[j].toString();
			var tmpIndex = tmpIndexKey.split(":")[0].toString();

			associationViewedRowSpreadIndex[tmpIndex] = 1;
		}

		// ===== swb_ȉꍇA炩߃wb_Z̕Lăo悤ɂĂ =====
		if ( getHeaderObjNum("ROW") > 1 ) {
			for ( var j = 0; j < getHeaderObjNum("ROW"); j++ ) {
				changeCellWidth(document.all("CrossHeader_CG" + j), 40, "modifyCrossHeaderWidth", "UP");
			}
		}

		// ===== c[o[̃`[g\{^̃J[\X^Cݒ肷 =====
		setChartBtnCursorStyle();

		// ===== c[o[̐Fݒ^Cv؂ւ{^ݒ肷 =====
		setColorTypeStyle();

		// ===== swb_Awb_Af[^\̕A𒲐 =====
		resizeArea();

		// ===== XN[CxgscrollView()Ƃ̑Ήt =====
		dataTableArea.onscroll = scrollView;

		// ===== Spreade[u̐FAf[^ǂݍ݁ASpread̕\(visibilityvisibleɕύX) =====
		refreshTableColor();

		// ===== `[g\GA\ =====
		displayChartArea();

	}

	// `[g\{^܂TABLEvf̃J[\X^Cݒ肷
	function setChartBtnCursorStyle() {
		var node = axesXMLData.selectSingleNode("/root/OlapInfo/ReportInfo/Report/displayScreenType");
		
		if(node.text == "0") { // Sʕ\i\j
			document.all("tblChartBtn").style.cursor = "default"; // ftHgij
		} else if ( (node.text == "1") || (node.text == "2") ) { // Ot\
			document.all("tblChartBtn").style.cursor = ""; // ݒiɎDIVɂAhandɂȂj
		}
	}

	// c[o[̐Fݒ^Cv؂ւ{^ݒ肷
	function setColorTypeStyle() {
		var node = axesXMLData.selectSingleNode("/root/OlapInfo/ReportInfo/Report/colorType");
		if(node.text == "1") {
			document.all("tblColorBtn").style.display = "block";
			document.all("tblHigtLightBtn").style.display = "none";
		} else if (node.text == "2") {
			document.all("tblColorBtn").style.display = "none";
			document.all("tblHigtLightBtn").style.display = "block";
		}
		
	}

	// `[g\GA\
	function displayChartArea() {
		var node = axesXMLData.selectSingleNode("/root/OlapInfo/ReportInfo/Report/displayScreenType");

		// Sʕ\i\ĵƂ́AOtރACRύX
		if (node.text == "0") {
			var selectedChartNo = axesXMLData.selectSingleNode("/root/OlapInfo/ReportInfo/Report/currentChartID").text;
			changeChartKindButton(selectedChartNo);
		}

		if ((node.text == "1")||(node.text == "2")) { // Ot\
			document.all("chartAreaDIV").style.visibility = "visible";
		}

		// Sʕ\iOtĵƂ́ASpread\AOt݂̂\
		if (node.text == "1") { // Sʕ\iOtj
			clickDisplayStyleMenu(1); // 1:Sʕ\iOtj

		// c\i\EOtĵƂ́ASpread\AOt݂̂\
		} else if (node.text == "2") { // \i\EOtj
			clickDisplayStyleMenu(2);  // 2:Sʕ\iOtj
		}

	}
	

	// HTML̃e[uɐFݒKpAɃf[^}Ăяo
	function refreshTableColor() {
		document.SpreadForm.action = "Controller?action=loadColorAct";
		document.SpreadForm.target = "loadingStatus";
		document.SpreadForm.submit();
	}


	// ===== T[oւ̃ANZXǂݒ ========================================
	function setLoadingStatus(status) {
		if ( (status != true) && (status != false) ) {
			return;
		}

		if (status == true) { // T[o[փANZX
			parent.spread_header.loadingStatus.loadingIMG.src = "./images/logo_anime.gif";
		} else { // T[o[ւ̃ANZXI
			parent.spread_header.loadingStatus.loadingIMG.src = "./images/logo_anime_stop.gif";
		}
	}

	// ============= X^C֘A֐ =====================================

	// swb_ƃf[^e[ũXN[ʒu킹
	function scrollView() {
		rowHeader.scrollTop = dataTableArea.scrollTop;
		colHeader.scrollLeft= dataTableArea.scrollLeft;
	}

	// swb_Awb_Af[^\̕BODYTCYɍ킹ĕύXB
	function resizeArea() {
		if ( document.body.clientWidth != 0 ) {

			var node = axesXMLData.selectSingleNode("/root/OlapInfo/ReportInfo/Report/displayScreenType");

			var newWidth  = ( document.body.clientWidth - rowHeader.offsetWidth ) 
			var areaHeight;
				if ((node.text=="0") || (node.text=="2")) { // \̓t[udisplay_areavŊ
					areaHeight = (document.all("tblToolBar").offsetHeight
									+ colHeader.offsetHeight
									+ spreadTable.rows[0].offsetHeight
									+ spreadTable.rows[1].offsetHeight
								 );
				} else if (node.text=="1") { // udisplay_areavɂ̓Ot\邽
					areaHeight = document.all("tblToolBar").offsetHeight;
				}

			var newHeight = ( document.body.clientHeight 
			                   - areaHeight
			                 );

			// swb_Af[^\̕їwb_Af[^\̍
			// ɂȂꍇ́A␳͍sȂȂ
			if ( newWidth <= 0 ) {
				return;
			} else if ( newHeight <= 0 ) {
				return;
			}

			colHeader.style.width      = newWidth;
			dataTableArea.style.width  = newWidth;

			rowHeader.style.height     = newHeight;
			dataTableArea.style.height = newHeight;

			// sEwb_Af[^e[ũXN[ʒu(XAY)킹
			scrollView();
		}
	}

// ===== bZ[W\ =============================================

	// [U[ɃbZ[W\
	function showMessage( id,arg1,arg2,arg3,arg4,arg5 ) {

		var message    = "";
		var arg1String = "";
		var arg2String = "";
		var arg3String = "";
		var arg4String = "";
		var arg5String = "";

		switch ( id ) {
		
			case "1" :
				if ( arg1 == "COL" ) {
					arg1String = "wb_";
				} else if ( arg1 == "ROW" ) {
					arg1String = "swb_";
				}
				message = arg1String + "ɂ͂Piȏ̃fBV܂̓W[KvłB";
				break;

			case "2" :
				if ( arg1 == "COL" ) {
					arg1String = "wb_";
				} else if ( arg1 == "ROW" ) {
					arg1String = "swb_";
				}
				message = arg1String + "ɂ͂Riȏ̃fBV܂̓W[͐ݒł܂B";
				break;

			case "3" :
				if ( arg2 == "COL" ) {
					arg2String = "wb_";
				} else if ( arg2 == "ROW" ) {
					arg2String = "swb_";
				}
				message = arg2String + "ɕ\łZ̍ől" + arg1 + "łB";
				break;

			case "4" :
				message = "|[gɕ\łZ̍ől" + arg1 + "łB";
				break;

			case "5" :
				message = "hsĂ܂BXB";
				break;

			// ZN^
			case "6" :
				message = "Iς݂̃o[Ƀo[܂B";
				break;

			// |[gۑ
			case "7" :
				message = "|[gۑ܂B";
				break;

			// OC̓`FbNi[U[pX[hj
			case "8" :
				message = "[U[уpX[h͂ĂB";
				break;

			// OC̓`FbNi[U[j
			case "9" :
				message = "[U[͂ĂB";
				break;

			// OC̓`FbNipX[hj
			case "10" :
				message = "pX[h͂ĂB";
				break;


		}

		alert( message );
	}


	// [U[ɊmF߂郁bZ[W\
	function showConfirm(msgId,arg1){
		var msg=new Array();
		msg["CFM4"] = "OAEg܂B낵łH";
		return confirm(msg[msgId]);
	}

// ====================================================================================

	// ʃt[ŃOAEgɎgp
	function logout_flow(element, contextPath) {
		if ( showConfirm("CFM4") ) {
			element.href = contextPath + "/Controller?action=logout";
			element.target="_top";
		} else {
			return;
		}
	}

// ===== `[g\֘A ==============================================================

	// `[g\XV	
	function reloadChart() {
	
		// T[oւ̃ANZX󋵂ݒ(C[W𓮂)
//		setLoadingStatus(true);

		// ݕ\Ăs/̏擾Ahiddenɕۑ
		// ieohŔ\ƂȂĂ郁o͊܂߂ȂBj
		setViewingColRowInfo();

		// Ot擾
		var currentChartIDNode = axesXMLData.selectSingleNode("/root/OlapInfo/ReportInfo/Report/currentChartID");

		// Ot\ΏۂƂȂt[AOt\GÃTCYݒ
		var targetFrame = null; // Ot\ΏۂƂȂt[
		var chartWidth;			// OtiC[Wt@Cj̕
		var chartHeight;		// OtiC[Wt@Cj̍

		var displayScreenTypeNode = axesXMLData.selectSingleNode("/root/OlapInfo/ReportInfo/Report/displayScreenType");
		if (displayScreenTypeNode.text == "0") { // Sʕ\i\j̏ꍇACi[t[^[Qbgɐݒ(Ot\킯ł͂Ȃ̂ŁAۂɂ͕\Ȃ_~[̃t[)
			targetFrame = "chart_area";
		} else if (displayScreenTypeNode.text == "1") { // Sʕ\iOtj̏ꍇACi[t[ɃOt\
			targetFrame = "chart_area";
			chartWidth = document.body.clientWidth-3;
			chartHeight = document.body.clientHeight - document.all("tblToolBar").offsetHeight-40;
//alert(chartWidth + "\n" + chartHeight);
			
			// iframe̍ύX
			document.all("chart_area").height = chartHeight;

		} else if (displayScreenTypeNode.text == "2") { // \i\AOtj̏ꍇAt[ɃOt\
			targetFrame = "chart_sub_area";

			dispChartSubArea(chartSubAreaInitialHeight); // \GA쐬A\GÃTCYɂAC[W쐬
			chartWidth = parent.chart_sub_area.document.body.clientWidth;
			chartHeight = parent.chart_sub_area.document.body.clientHeight;
		}

		// `[g̎ރ{^\̃{^ύX
		var memNo = axesXMLData.selectSingleNode("/root/OlapInfo/ReportInfo/Report/currentChartID").text;
		changeChartKindButton(memNo);

		// T[o[֑MAʃ^CvAftHg`[g^CvXVƂƂɁANCAg̃`[gXV
		document.SpreadForm.action = "Controller?action=getChartInfo&chartID=" + currentChartIDNode.text + "&displayScreenType=" + displayScreenTypeNode.text + "&chartWidth=" + chartWidth + "&chartHeight=" + chartHeight;
		document.SpreadForm.target = targetFrame;
		document.SpreadForm.submit();
	}
